<h1 align="center">BirTodo</h1>
<p align="center">
    ~ an extremely simple command-line interface for users to save their to-dos locally.
</p>

<h1 align="center">Some info</h1>
<ol>
    <li>Database: it uses the local `SQLite` database.</li>
    <li>Features: todo add, remove, edit, show and export commands.</li>
    <li>Documenting: every method is filled up with a corresponding docstring.</li>
</ol>